betty.cli package - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.cli package

## Subpackages

- betty.cli.commands package
  - Submodules
    - betty.cli.commands.clear_caches module
    - betty.cli.commands.config module
    - betty.cli.commands.demo module
    - betty.cli.commands.dev_init_translation module
    - betty.cli.commands.dev_update_translations module
    - betty.cli.commands.docs module
    - betty.cli.commands.generate module
    - betty.cli.commands.serve module
  - Module contents
    - `COMMAND_REPOSITORY`
    - `Command`
      - `Command.click_command()`
      - `Command.plugin_description()`
      - `Command.plugin_id()`
      - `Command.plugin_label()`
    - `command()`
    - `pass_app()`
    - `pass_project()`

## Module contents

Provide the Command Line Interface.

betty.cli.catch_exceptions() → Iterator[None]

  Catch and log all exceptions.